@@ -1,7 +1,7 @@
 /*
  * InspIRCd -- Internet Relay Chat Daemon
  *
- *   Copyright (C) 2019 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2019, 2022 Sadie Powell <sadie@witchery.services>
  *
  * This file is part of InspIRCd.  InspIRCd is free software: you can
  * redistribute it and/or modify it under the terms of the GNU General Public
@@ -73,8 +73,8 @@ private:
 	}
 
 	/** Retrieves the two character country code for this location. */
-	std::string GetCode() const { return code; }
+	const std::string& GetCode() const { return code; }
 
 	/** Retrieves the country name for this location. */
-	std::string GetName() const { return name; }
+	const std::string& GetName() const { return name; }
 };
