@@ -1,7 +1,7 @@
 #
 # InspIRCd -- Internet Relay Chat Daemon
 #
-#   Copyright (C) 2014-2017, 2019-2020 Sadie Powell <sadie@witchery.services>
+#   Copyright (C) 2014-2017, 2019-2021 Sadie Powell <sadie@witchery.services>
 #
 # This file is part of InspIRCd.  InspIRCd is free software: you can
 # redistribute it and/or modify it under the terms of the GNU General Public
@@ -17,13 +17,9 @@
 #
 
 
-BEGIN {
-	require 5.10.0;
-}
-
 package make::common;
 
-use feature ':5.10';
+use v5.10.0;
 use strict;
 use warnings FATAL => qw(all);
 
@@ -49,7 +45,7 @@ sub create_directory($$) {
 }
 
 sub execute(@) {
-	print_format "<|BOLD \$|> @_\n";
+	say console_format "<|BOLD \$|> @_";
 	return system @_;
 }
 
