@@ -2,11 +2,10 @@
  * InspIRCd -- Internet Relay Chat Daemon
  *
  *   Copyright (C) 2018 linuxdaemon <linuxdaemon.irc@gmail.com>
- *   Copyright (C) 2013-2014, 2016-2021 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2013-2014, 2016-2022 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2013 ChrisTX <xpipe@hotmail.de>
  *   Copyright (C) 2012-2014 Attila Molnar <attilamolnar@hush.com>
  *   Copyright (C) 2012 Robby <robby@chatbelgie.be>
- *   Copyright (C) 2010 Craig Edwards <brain@inspircd.org>
  *   Copyright (C) 2009-2010 Daniel De Graaf <danieldg@inspircd.org>
  *
  * This file is part of InspIRCd.  InspIRCd is free software: you can
@@ -476,6 +475,30 @@ void ParseStack::DoInclude(ConfigTag* tag, int flags)
 	}
 }
 
+namespace
+{
+	void CheckOwnership(const std::string& path)
+	{
+#ifndef _WIN32
+		struct stat pathinfo;
+		if (stat(path.c_str(), &pathinfo))
+			return; // Will be handled when fopen fails.
+
+		if (getegid() != pathinfo.st_gid)
+		{
+			ServerInstance->Logs->Log("CONFIG", LOG_DEFAULT, "Possible configuration error: %s is owned by group %u but the server is running as group %u.",
+				path.c_str(), pathinfo.st_gid, getegid());
+		}
+
+		if (geteuid() != pathinfo.st_uid)
+		{
+			ServerInstance->Logs->Log("CONFIG", LOG_DEFAULT, "Possible configuration error: %s is owned by user %u but the server is running as user %u.",
+				path.c_str(), pathinfo.st_uid, geteuid());
+		}
+#endif
+	}
+}
+
 void ParseStack::DoReadFile(const std::string& key, const std::string& name, int flags, bool exec)
 {
 	if (flags & FLAG_NO_INC)
@@ -483,7 +506,10 @@ void ParseStack::DoReadFile(const std::string& key, const std::string& name, int
 	if (exec && (flags & FLAG_NO_EXEC))
 		throw CoreException("Invalid <execfiles> tag in file included with noexec=\"yes\"");
 
-	std::string path = ServerInstance->Config->Paths.PrependConfig(name);
+	const std::string path = ServerInstance->Config->Paths.PrependConfig(name);
+	if (!exec)
+		CheckOwnership(path);
+
 	FileWrapper file(exec ? popen(name.c_str(), "r") : fopen(path.c_str(), "r"), exec);
 	if (!file)
 		throw CoreException("Could not read \"" + path + "\" for \"" + key + "\" file");
@@ -531,6 +557,8 @@ ParseStack::ParseStack(ServerConfig* conf)
 	vars["irc.bold"]          = "\x02";
 	vars["irc.color"]         = "\x03";
 	vars["irc.colour"]        = "\x03";
+	vars["irc.hexcolor"]      = "\x04";
+	vars["irc.hexcolour"]     = "\x04";
 	vars["irc.italic"]        = "\x1D";
 	vars["irc.monospace"]     = "\x11";
 	vars["irc.reset"]         = "\x0F";
@@ -545,8 +573,10 @@ bool ParseStack::ParseFile(const std::string& path, int flags, const std::string
 	if (stdalgo::isin(reading, path))
 		throw CoreException((isexec ? "Executable " : "File ") + path + " is included recursively (looped inclusion)");
 
-	/* It's not already included, add it to the list of files we've loaded */
+	if (!isexec)
+		CheckOwnership(path);
 
+	/* It's not already included, add it to the list of files we've loaded */
 	FileWrapper file((isexec ? popen(path.c_str(), "r") : fopen(path.c_str(), "r")), isexec);
 	if (!file)
 	{
@@ -607,7 +637,7 @@ std::string ConfigTag::getString(const std::string& key, const std::string& def,
 	if (res.length() < minlen || res.length() > maxlen)
 	{
 		ServerInstance->Logs->Log("CONFIG", LOG_DEFAULT, "WARNING: The length of <%s:%s> is not between %ld and %ld; value set to %s.",
-			tag.c_str(), key.c_str(), minlen, maxlen, def.c_str());
+			tag.c_str(), key.c_str(), (unsigned long)minlen, (unsigned long)maxlen, def.c_str());
 		return def;
 	}
 	return res;
@@ -755,6 +785,16 @@ bool ConfigTag::getBool(const std::string &key, bool def)
 	return def;
 }
 
+unsigned char ConfigTag::getCharacter(const std::string &key, unsigned char def)
+{
+	std::string result;
+	if (!readString(key, result) || result.size() != 1)
+		return def;
+
+	return result[0];
+}
+
+
 std::string ConfigTag::getTagLocation()
 {
 	return src_name + ":" + ConvToStr(src_line);
