@@ -3,17 +3,16 @@
  *
  *   Copyright (C) 2020 Matt Schatz <genius3000@g3k.solutions>
  *   Copyright (C) 2019 linuxdaemon <linuxdaemon.irc@gmail.com>
- *   Copyright (C) 2013-2014, 2016-2021 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2013-2014, 2016-2022 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2013 Daniel Vassdal <shutter@canternet.org>
  *   Copyright (C) 2012-2017 Attila Molnar <attilamolnar@hush.com>
  *   Copyright (C) 2012-2013, 2016 Adam <Adam@anope.org>
  *   Copyright (C) 2012 Robby <robby@chatbelgie.be>
  *   Copyright (C) 2012 ChrisTX <xpipe@hotmail.de>
  *   Copyright (C) 2009-2010 Daniel De Graaf <danieldg@inspircd.org>
- *   Copyright (C) 2009 Uli Schlachter <psychon@inspircd.org>
  *   Copyright (C) 2008 Robin Burchell <robin+git@viroteck.net>
  *   Copyright (C) 2008 John Brooks <special@inspircd.org>
- *   Copyright (C) 2007-2008, 2010 Craig Edwards <brain@inspircd.org>
+ *   Copyright (C) 2007-2008 Craig Edwards <brain@inspircd.org>
  *   Copyright (C) 2007 Dennis Friis <peavey@inspircd.org>
  *   Copyright (C) 2006 Oliver Lupton <om@inspircd.org>
  *
@@ -94,6 +93,10 @@
 # include <gcrypt.h>
 #endif
 
+#if INSPIRCD_GNUTLS_HAS_VERSION(3, 6, 0)
+# define GNUTLS_AUTO_DH
+#endif
+
 #ifdef _WIN32
 # pragma comment(lib, "libgnutls-30.lib")
 #endif
@@ -194,9 +197,12 @@ namespace GnuTLS
 		{
 			// As older versions of gnutls can't do this, let's disable it where needed.
 #ifdef GNUTLS_HAS_MAC_GET_ID
+# if INSPIRCD_GNUTLS_HAS_VERSION(3, 2, 2)
+			hash = gnutls_digest_get_id(hashname.c_str());
+# else
 			// As gnutls_digest_algorithm_t and gnutls_mac_algorithm_t are mapped 1:1, we can do this
-			// There is no gnutls_dig_get_id() at the moment, but it may come later
 			hash = (gnutls_digest_algorithm_t)gnutls_mac_get_id(hashname.c_str());
+# endif
 			if (hash == GNUTLS_DIG_UNKNOWN)
 				throw Exception("Unknown hash type " + hashname);
 
@@ -220,6 +226,7 @@ namespace GnuTLS
 		gnutls_digest_algorithm_t get() const { return hash; }
 	};
 
+#ifndef GNUTLS_AUTO_DH
 	class DHParams
 	{
 		gnutls_dh_params_t dh_params;
@@ -246,6 +253,7 @@ namespace GnuTLS
 
 		const gnutls_dh_params_t& get() const { return dh_params; }
 	};
+#endif
 
 	class X509Key
 	{
@@ -443,9 +451,11 @@ namespace GnuTLS
 
 	class CertCredentials
 	{
+#ifndef GNUTLS_AUTO_DH
 		/** DH parameters associated with these credentials
 		 */
 		SMART_PTR<DHParams> dh;
+#endif
 
 	 protected:
 		gnutls_certificate_credentials_t cred;
@@ -468,6 +478,7 @@ namespace GnuTLS
 			gnutls_credentials_set(sess, GNUTLS_CRD_CERTIFICATE, cred);
 		}
 
+#ifndef GNUTLS_AUTO_DH
 		/** Set the given DH parameters to be used with these credentials
 		 */
 		void SetDH(SMART_PTR<DHParams>& DH)
@@ -475,6 +486,7 @@ namespace GnuTLS
 			dh = DH;
 			gnutls_certificate_set_dh_params(cred, dh->get());
 		}
+#endif
 	};
 
 	class X509Credentials : public CertCredentials
@@ -655,8 +667,10 @@ namespace GnuTLS
 
 			std::string certstr;
 			std::string keystr;
-			SMART_PTR<DHParams> dh;
 
+#ifndef GNUTLS_AUTO_DH
+			SMART_PTR<DHParams> dh;
+#endif
 			std::string priostr;
 			unsigned int mindh;
 			std::string hashstr;
@@ -668,7 +682,9 @@ namespace GnuTLS
 				: name(profilename)
 				, certstr(ReadFile(tag->getString("certfile", "cert.pem", 1)))
 				, keystr(ReadFile(tag->getString("keyfile", "key.pem", 1)))
+#ifndef GNUTLS_AUTO_DH
 				, dh(DHParams::Import(ReadFile(tag->getString("dhfile", "dhparams.pem", 1))))
+#endif
 				, priostr(GetPrioStr(profilename, tag))
 				, mindh(tag->getUInt("mindhbits", 1024))
 				, hashstr(tag->getString("hash", "md5", 1))
@@ -703,7 +719,9 @@ namespace GnuTLS
 			, outrecsize(config.outrecsize)
 			, requestclientcert(config.requestclientcert)
 		{
+#ifndef GNUTLS_AUTO_DH
 			x509cred.SetDH(config.dh);
+#endif
 			x509cred.SetCA(config.ca, config.crl);
 		}
 		/** Set up the given session with the settings in this profile
@@ -1184,7 +1202,7 @@ info_done_dealloc:
 
 	bool GetServerName(std::string& out) const CXX11_OVERRIDE
 	{
-		std::vector<char> nameBuffer;
+		std::vector<char> nameBuffer(1);
 		size_t nameLength = 0;
 		unsigned int nameType = GNUTLS_NAME_DNS;
 
