@@ -4,16 +4,16 @@
  *   Copyright (C) 2020 Matt Schatz <genius3000@g3k.solutions>
  *   Copyright (C) 2019 linuxdaemon <linuxdaemon.irc@gmail.com>
  *   Copyright (C) 2017 Wade Cline <wadecline@hotmail.com>
- *   Copyright (C) 2014, 2016 Adam <Adam@anope.org>
+ *   Copyright (C) 2016 Adam <Adam@anope.org>
  *   Copyright (C) 2014 Julien Vehent <julien@linuxwall.info>
- *   Copyright (C) 2013-2014, 2016-2021 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2013-2014, 2016-2022 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2012-2017 Attila Molnar <attilamolnar@hush.com>
  *   Copyright (C) 2012 Robby <robby@chatbelgie.be>
  *   Copyright (C) 2012 ChrisTX <xpipe@hotmail.de>
  *   Copyright (C) 2009-2010 Daniel De Graaf <danieldg@inspircd.org>
  *   Copyright (C) 2008 Robin Burchell <robin+git@viroteck.net>
  *   Copyright (C) 2007 Dennis Friis <peavey@inspircd.org>
- *   Copyright (C) 2006-2008, 2010 Craig Edwards <brain@inspircd.org>
+ *   Copyright (C) 2006-2008 Craig Edwards <brain@inspircd.org>
  *   Copyright (C) 2006 Oliver Lupton <om@inspircd.org>
  *
  * This file is part of InspIRCd.  InspIRCd is free software: you can
@@ -77,8 +77,8 @@
 #endif
 
 #ifdef _WIN32
-# pragma comment(lib, "ssleay32.lib")
-# pragma comment(lib, "libeay32.lib")
+# pragma comment(lib, "libcrypto.lib")
+# pragma comment(lib, "libssl.lib")
 #endif
 
 // Compatibility layer to allow OpenSSL 1.0 to use the 1.1 API.
@@ -102,6 +102,9 @@
 
 #else
 # define INSPIRCD_OPENSSL_OPAQUE_BIO
+# if OPENSSL_VERSION_NUMBER >= 0x30000000L
+#  define INSPIRCD_OPENSSL_AUTO_DH
+# endif
 #endif
 
 static bool SelfSigned = false;
@@ -124,6 +127,7 @@ namespace OpenSSL
 			: ModuleException(reason) { }
 	};
 
+#ifndef INSPIRCD_OPENSSL_AUTO_DH
 	class DHParams
 	{
 		DH* dh;
@@ -152,6 +156,7 @@ namespace OpenSSL
 			return dh;
 		}
 	};
+#endif
 
 	class Context
 	{
@@ -190,19 +195,26 @@ namespace OpenSSL
 			SSL_CTX_free(ctx);
 		}
 
+#ifndef INSPIRCD_OPENSSL_AUTO_DH
 		bool SetDH(DHParams& dh)
 		{
 			ERR_clear_error();
 			return (SSL_CTX_set_tmp_dh(ctx, dh.get()) >= 0);
 		}
+#endif
 
 #ifndef OPENSSL_NO_ECDH
 		void SetECDH(const std::string& curvename)
 		{
 			int nid = OBJ_sn2nid(curvename.c_str());
-			if (nid == 0)
+			if (nid == NID_undef)
 				throw Exception("Unknown curve: " + curvename);
 
+# if OPENSSL_VERSION_NUMBER >= 0x10101000L
+			ERR_clear_error();
+			if (!SSL_CTX_set1_groups(ctx, &nid, 1))
+				throw Exception("Couldn't set ECDH curve");
+# else
 			EC_KEY* eckey = EC_KEY_new_by_curve_name(nid);
 			if (!eckey)
 				throw Exception("Unable to create EC key object");
@@ -212,6 +224,7 @@ namespace OpenSSL
 			EC_KEY_free(eckey);
 			if (!ret)
 				throw Exception("Couldn't set ECDH parameters");
+# endif
 		}
 #endif
 
@@ -329,9 +342,11 @@ namespace OpenSSL
 		 */
 		const std::string name;
 
+#ifndef INSPIRCD_OPENSSL_AUTO_DH
 		/** DH parameters in use
 		 */
 		DHParams dh;
+#endif
 
 		/** OpenSSL makes us have two contexts, one for servers and one for clients
 		 */
@@ -393,6 +408,12 @@ namespace OpenSSL
 				setoptions |= SSL_OP_NO_TLSv1_2;
 #endif
 
+#ifdef SSL_OP_NO_TLSv1_3
+			// Enable TLSv1.3 by default.
+			if (!tag->getBool("tlsv13", true))
+				setoptions |= SSL_OP_NO_TLSv1_3;
+#endif
+
 			if (!setoptions && !clearoptions)
 				return; // Nothing to do
 
@@ -404,14 +425,18 @@ namespace OpenSSL
 	 public:
 		Profile(const std::string& profilename, ConfigTag* tag)
 			: name(profilename)
+#ifndef INSPIRCD_OPENSSL_AUTO_DH
 			, dh(ServerInstance->Config->Paths.PrependConfig(tag->getString("dhfile", "dhparams.pem", 1)))
+#endif
 			, ctx(SSL_CTX_new(SSLv23_server_method()))
 			, clientctx(SSL_CTX_new(SSLv23_client_method()))
 			, allowrenego(tag->getBool("renegotiation")) // Disallow by default
 			, outrecsize(tag->getUInt("outrecsize", 2048, 512, 16384))
 		{
+#ifndef INSPIRCD_OPENSSL_AUTO_DH
 			if ((!ctx.SetDH(dh)) || (!clientctx.SetDH(dh)))
 				throw Exception("Couldn't set DH parameters");
+#endif
 
 			const std::string hash = tag->getString("hash", "md5", 1);
 			digest = EVP_get_digestbyname(hash.c_str());
@@ -443,7 +468,7 @@ namespace OpenSSL
 			}
 
 #ifndef OPENSSL_NO_ECDH
-			const std::string curvename = tag->getString("ecdhcurve", "prime256v1", 1);
+			const std::string curvename = tag->getString("ecdhcurve", "prime256v1");
 			if (!curvename.empty())
 				ctx.SetECDH(curvename);
 #endif
@@ -682,7 +707,7 @@ class OpenSSLIOHook : public SSLIOHook
 		X509_free(cert);
 	}
 
-	static void GetDNString(const X509_NAME* x509name, std::string& out)
+	static void GetDNString(X509_NAME* x509name, std::string& out)
 	{
 		char buf[512];
 		X509_NAME_oneline(x509name, buf, sizeof(buf));
