@@ -4,11 +4,9 @@
  *   Copyright (C) 2021 Herman <GermanAizek@yandex.ru>
  *   Copyright (C) 2020 Matt Schatz <genius3000@g3k.solutions>
  *   Copyright (C) 2013-2014, 2016 Attila Molnar <attilamolnar@hush.com>
- *   Copyright (C) 2013, 2018-2021 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2013, 2018-2022 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2012, 2019 Robby <robby@chatbelgie.be>
- *   Copyright (C) 2010 Craig Edwards <brain@inspircd.org>
  *   Copyright (C) 2009-2010 Daniel De Graaf <danieldg@inspircd.org>
- *   Copyright (C) 2009 Uli Schlachter <psychon@inspircd.org>
  *   Copyright (C) 2007 Dennis Friis <peavey@inspircd.org>
  *   Copyright (C) 2006-2007 Robin Burchell <robin+git@viroteck.net>
  *
@@ -234,6 +232,7 @@ class CommandCheck : public Command
 					context.Write("connectclass", classname);
 
 				context.Write("exempt", localtarget->exempt ? "yes" : "no");
+				context.Write("serializer", localtarget->serializer->name.substr(11));
 			}
 			else
 				context.Write("onip", targetuser->GetIPString());
@@ -276,7 +275,7 @@ class CommandCheck : public Command
 				 * Unlike Asuka, I define a clone as coming from the same host. --w00t
 				 */
 				const UserManager::CloneCounts& clonecount = ServerInstance->Users->GetCloneCounts(i->first);
-				context.Write("member", InspIRCd::Format("%u %s%s (%s)", clonecount.global,
+				context.Write("member", InspIRCd::Format("%u %s%s (%s\x0F)", clonecount.global,
 					i->second->GetAllPrefixChars().c_str(), i->first->GetFullHost().c_str(),
 					i->first->GetRealName().c_str()));
 			}
