@@ -3,7 +3,7 @@
  *
  *   Copyright (C) 2019 Robby <robby@chatbelgie.be>
  *   Copyright (C) 2018 linuxdaemon <linuxdaemon.irc@gmail.com>
- *   Copyright (C) 2017-2018, 2020 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2017-2018, 2020-2021 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2014 JustArchi <JustArchi@JustArchi.net>
  *   Copyright (C) 2014 Attila Molnar <attilamolnar@hush.com>
  *   Copyright (C) 2013 Daniel Vassdal <shutter@canternet.org>
@@ -127,7 +127,7 @@ class ModuleFlashPD : public Module
 				if (!stdalgo::string::equalsci(ls->bind_tag->getString("type", "clients", 1), "clients"))
 					continue;
 
-				if (!ls->bind_tag->getString("ssl").empty())
+				if (!ls->bind_tag->getString("sslprofile", ls->bind_tag->getString("ssl")).empty())
 					continue;
 
 				to_ports.append(ConvToStr(ls->bind_sa.port())).push_back(',');
