@@ -2,7 +2,7 @@
  * InspIRCd -- Internet Relay Chat Daemon
  *
  *   Copyright (C) 2019 Robby <robby@chatbelgie.be>
- *   Copyright (C) 2013, 2017-2018, 2020-2021 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2013, 2017-2018, 2020-2022 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2012-2014, 2016 Attila Molnar <attilamolnar@hush.com>
  *   Copyright (C) 2010 Craig Edwards <brain@inspircd.org>
  *   Copyright (C) 2009-2010 Daniel De Graaf <danieldg@inspircd.org>
@@ -113,7 +113,7 @@ class ModuleOjoin : public Module
  public:
 
 	ModuleOjoin()
-		: np(this, ServerInstance->Config->ConfValue("ojoin")->getString("prefix").c_str()[0])
+		: np(this, ServerInstance->Config->ConfValue("ojoin")->getCharacter("prefix"))
 		, mycommand(this, np)
 	{
 	}
