@@ -1,7 +1,7 @@
 /*
  * InspIRCd -- Internet Relay Chat Daemon
  *
- *   Copyright (C) 2017 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2017, 2020 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2016 Attila Molnar <attilamolnar@hush.com>
  *
  * This file is part of InspIRCd.  InspIRCd is free software: you can
@@ -166,8 +166,8 @@ class SHA1Context
 class SHA1HashProvider : public HashProvider
 {
  public:
- 	SHA1HashProvider(Module* mod)
-		: HashProvider(mod, "hash/sha1", 20, 64)
+	SHA1HashProvider(Module* mod)
+		: HashProvider(mod, "sha1", 20, 64)
 	{
 	}
 
