@@ -34,7 +34,7 @@
 /*
  * The server list in InspIRCd is maintained as two structures
  * which hold the data in different ways. Most of the time, we
- * want to very quicky obtain three pieces of information:
+ * want to very quickly obtain three pieces of information:
  *
  * (1) The information on a server
  * (2) The information on the server we must send data through
@@ -55,10 +55,10 @@
  * CONNECTING:	indicates an outbound socket which is
  *							waiting to be writeable.
  * WAIT_AUTH_1:	indicates the socket is outbound and
- * 							has successfully connected, but has not
+ *							has successfully connected, but has not
  *							yet sent and received SERVER strings.
  * WAIT_AUTH_2:	indicates that the socket is inbound
- * 							but has not yet sent and received
+ *							but has not yet sent and received
  *							SERVER strings.
  * CONNECTED:   represents a fully authorized, fully
  *							connected server.
