@@ -4,13 +4,12 @@
  *   Copyright (C) 2019 iwalkalone <iwalkalone69@gmail.com>
  *   Copyright (C) 2019 Matt Schatz <genius3000@g3k.solutions>
  *   Copyright (C) 2013-2016, 2018 Attila Molnar <attilamolnar@hush.com>
- *   Copyright (C) 2013, 2018-2021 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2013, 2018-2020, 2022 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2013, 2015 Adam <Adam@anope.org>
  *   Copyright (C) 2013 Daniel Vassdal <shutter@canternet.org>
  *   Copyright (C) 2012, 2019 Robby <robby@chatbelgie.be>
  *   Copyright (C) 2009-2010 Daniel De Graaf <danieldg@inspircd.org>
- *   Copyright (C) 2009 Uli Schlachter <psychon@inspircd.org>
- *   Copyright (C) 2008-2010 Craig Edwards <brain@inspircd.org>
+ *   Copyright (C) 2008-2009 Craig Edwards <brain@inspircd.org>
  *   Copyright (C) 2008 Robin Burchell <robin+git@viroteck.net>
  *
  * This file is part of InspIRCd.  InspIRCd is free software: you can
@@ -157,16 +156,14 @@ void UserManager::AddUser(int socket, ListenSocket* via, irc::sockets::sockaddrs
 		ListenSocket::IOHookProvRef& iohookprovref = *i;
 		if (!iohookprovref)
 		{
-			if (!iohookprovref.GetProvider().empty())
-			{
-				ServerInstance->Logs->Log("USERS", LOG_DEBUG, "Non-existent I/O hook '%s' in <bind:%s> tag at %s",
-					iohookprovref.GetProvider().c_str(),
-					i == via->iohookprovs.begin() ? "hook" : "sslprofile",
-					via->bind_tag->getTagLocation().c_str());
-				this->QuitUser(New, "Internal error handling connection");
-				return;
-			}
-			continue;
+			if (iohookprovref.GetProvider().empty())
+				continue;
+
+			const char* hooktype = i == via->iohookprovs.begin() ? "hook" : "sslprofile";
+			ServerInstance->Logs->Log("USERS", LOG_DEFAULT, "Non-existent I/O hook '%s' in <bind:%s> tag at %s",
+				iohookprovref.GetProvider().c_str(), hooktype, via->bind_tag->getTagLocation().c_str());
+			this->QuitUser(New, InspIRCd::Format("Internal error handling connection (misconfigured %s)", hooktype));
+			return;
 		}
 
 		iohookprovref->OnAccept(eh, client, server);
